package VMOMI::HostServicePolicy;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
